/*
 * l_call.c - call Lua from Python
 *
 * Copyright 2006   firkanim@mail.datanet.hu (Fazekas Laszlo)
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <Python.h>

#include "l_call.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <lualib.h>
#include <lauxlib.h>

#if (LUA_VERSION_NUM < 501)
#	define LUA50
#else
#	undef LUA50
#endif

int lcall_init(LCall_Struc *lcs) {
	lua_State *L;

#ifdef LUA50
	L= lua_open();
	lcs->L= L;

	if (L != NULL) {
		luaopen_base(L);
		luaopen_table(L);
		luaopen_io(L);
		luaopen_string(L);
		luaopen_math(L);
		luaopen_debug(L);
		luaopen_loadlib(L);
		lua_settop(L, 0);
		return 0;
	}
#else
	L= luaL_newstate();
	lcs->L= L;

	if (L != NULL) {
		luaL_openlibs(L);
		return 0;
	}
#endif
	return 1;
}

void lcall_exit(LCall_Struc *lcs) {

	if (lcs->L != NULL) {
		lua_close(lcs->L);
		lcs->L= NULL;
	}
}

/* execute a lua chunk from a string */

int lcall_dostring(LCall_Struc *lcs, const char *cmd) {
	lua_State *L= lcs->L;

	if (L == NULL) return 1;

#ifdef LUA50
	return lua_dostring(L,cmd);
#else
	return luaL_dostring(L,cmd);
#endif
}
